@@ -1,7 +1,7 @@
 as.CTD <- function(S, T, p, header=NULL, filename=NA,ship=NA,scientist=NA,institute=NA,address=NA,
-cruise=NA,mooring=NA,date=NA,start.time=NA,start.time.list=NA,
-latitude=NA,latitude.dec=NA,
-longitude=NA,longitude.dec=NA,
+cruise=NA,station=NA,
+date=NA,start.time=NA,
+latitude=NA, longitude=NA,
 recovery=NA,
 water.depth=NA,
 sample.interval=NA)
@@ -17,14 +17,11 @@ sample.interval=NA)
               	institute=institute,
               	address=address,
               	cruise=cruise,
-              	mooring=mooring,
+              	station=station,
               	date=date,
 	      		start.time=start.time,
-	      		start.time.list=start.time.list,
               	latitude=latitude,
-              	latitude.dec=latitude.dec,
               	longitude=longitude,
-              	longitude.dec=longitude.dec,
               	recovery=recovery,
               	water.depth=water.depth,
               	sample.interval=sample.interval,
